import os

#user_dir = os.path.expanduser("~") # the homedir
user_dir = "/home/user/"                   # debug
config_dir = os.path.join(user_dir,".nqaap/")
book_dir = os.path.join(user_dir,"MyDocs/Audiobooks/")

def get_books():
    return [f for f in os.listdir(book_dir) if os.path.isdir(os.path.join(book_dir, f))]
